#!/usr/bin/python
import gtk
import os

SEPERATOR=" || "

class MainApp:
    def __init__(self):
        #create Treeview
        self.treeview=gtk.TreeView()
        self.treeview.show()
        column=gtk.TreeViewColumn("Title",gtk.CellRendererText(),text=0)
        column1=gtk.TreeViewColumn("Command",gtk.CellRendererText(),text=1)
        self.treeview.insert_column(column,0)
        #self.treeview.insert_column(column1,1)
        
        #create list store
        self.liststore=gtk.ListStore(str,str)
        
        #set model for treeview
        self.treeview.set_model(self.liststore)
        self.treeview.set_property("search-column",0)
        self.treeview.set_property("rules-hint",True)
        self.treeview.connect("row-activated",self.on_row_activate)
        self.treeview.connect("cursor-changed",self.on_row_select)
        
        #create button
        self.refreshbutton=gtk.Button("Refresh")
        self.refreshbutton.connect("clicked",lambda x:self.fill_list())
        
        #create scrolled window
        scrolled=gtk.ScrolledWindow()
        scrolled.add(self.treeview)
        
        #create statusbar
        self.statusbar=gtk.Statusbar()
        
        #create vbox
        vbox=gtk.VBox()
        vbox.pack_start(scrolled)
        vbox.pack_start(self.refreshbutton,expand=False)
        vbox.pack_start(self.statusbar,expand=False)
        vbox.show_all()
        
        #create window
        self.window=gtk.Window()
        self.window.set_title("Command Shortcuts Manager")
        self.window.set_size_request(250, 400)
        #self.window.set_decorated(False)
        #self.window.set_keep_below(True)
        self.window.stick()
        self.window.set_position(gtk.WIN_POS_MOUSE)
        self.window.set_property("skip-taskbar-hint",True)
        self.window.set_property("skip-pager-hint",True)
        self.window.show_all()
        self.window.hide()
        self.window.connect("delete-event",self.on_delete)
        self.window.add(vbox)
        
        #status icon
        self.statusicon=gtk.StatusIcon()
        self.statusicon.set_from_icon_name('text-editor')
        self.statusicon.set_tooltip("Command shorcuts manager")
        self.statusicon.connect('activate',self.on_icon_click)
        self.statusicon.connect('popup-menu',self.on_icon_popup)
        
        #fill the list
        self.fill_list()
    
    def fill_list(self):
        """Fill the list of commands"""
        commands=self.load_commands()
        self.liststore.clear()
        for comm in commands:
            self.liststore.append(comm)
            
    def load_commands(self):
        """Load commands from file"""
        path=os.path.expanduser("~/commands.txt")
        try:
            plik=open(path)
            lines=plik.readlines()
            plik.close()
        except IOError:
            lines=[]
        
        commands=[]
        #parse file
        for line in  lines:
            text=line.split(SEPERATOR)
            if len(text)<2:continue
            text=text[0].strip(),text[1].strip()
            if text[0].startswith("#"):continue
            commands.append(text)
        return commands
        
    def on_icon_click(self,widget):
        """On icon click"""
        if self.window.get_property("visible"):
            self.window.hide()
        else:
            self.window.show()
    
    def on_icon_popup(self,widget,button,time):
        menu=gtk.Menu()
        popmenu=gtk.MenuItem("Quit")
        popmenu.connect('activate',self.on_close)
        menu.append(popmenu)
        menu.show_all()

        menu.popup(None,None,None,button,time)
        
    def on_delete(self,widget,a):
        self.window.hide()
        return True
        
    def on_close(self,widget):
        gtk.main_quit()
    
    def on_row_select(self,widget):
        """On row select"""
        sel=self.get_selection()
        if sel:
            self.statusbar.push(0,sel[1])
            self.statusbar.set_tooltip_text(sel[1])
        
    def on_row_activate(self,widget,path,column):
        """Exec column command"""
        rowdata=self.get_selection()
        if rowdata:os.system(rowdata[1]+" &")
    
    def get_selection(self):
        """Get selected rows data [title,command] or None"""
        if self.treeview.get_selection():
            row=self.treeview.get_selection().get_selected()
            if row[1]:
                title=self.liststore.get_value(row[1],0)
                command=self.liststore.get_value(row[1],1)
                return [title,command]
        else:return False
        
if __name__=="__main__":
    MainApp()
    gtk.main()